==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/PolarAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarAreaSeriesDescription } from "./PolarAreaSeriesDescription";
/**
 * @hidden
 */
export let PolarAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarAreaSeriesDescriptionMetadata.a == null) {
                PolarAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarAreaSeriesDescriptionMetadata.c(PolarAreaSeriesDescriptionMetadata.a);
            }
            if (a.j(PolarAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(PolarAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            PolarAreaSeriesDescriptionMetadata.b(a);
            a.aa("PolarAreaSeries", () => new PolarAreaSeriesDescription());
            a.z("PolarAreaSeries", PolarAreaSeriesDescriptionMetadata.a);
        }
    }
    PolarAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarAreaSeriesDescriptionMetadata, 'PolarAreaSeriesDescriptionMetadata');
    PolarAreaSeriesDescriptionMetadata.a = null;
    return PolarAreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PolarAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarAreaSeriesDescription } from "./PolarAreaSeriesDescription";
/**
 * @hidden
 */
export let PolarAreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PolarAreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PolarAreaSeriesDescriptionMetadata.a == null) {
                PolarAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PolarAreaSeriesDescriptionMetadata.c(PolarAreaSeriesDescriptionMetadata.a);
            }
            if (a.k(PolarAreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(PolarAreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            PolarLineSeriesBaseDescriptionMetadata.c(a);
            a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
            a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
        }
        static d(a) {
            PolarAreaSeriesDescriptionMetadata.b(a);
            a.ac("PolarAreaSeries", () => new PolarAreaSeriesDescription());
            a.ab("PolarAreaSeries", PolarAreaSeriesDescriptionMetadata.a);
        }
    }
    PolarAreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PolarAreaSeriesDescriptionMetadata, 'PolarAreaSeriesDescriptionMetadata');
    PolarAreaSeriesDescriptionMetadata.a = null;
    return PolarAreaSeriesDescriptionMetadata;
})();
